==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/PlanWsparciaMieszkanca.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class PlanWsparciaMieszkanca extends GenericDPSObject {
    /**
     * PLAN_WSPARCIA_MIESZKANCA.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * PLAN_WSPARCIA_MIESZKANCA.EWIDENCJA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long ewidencjaId;

    /**
     * PLAN_WSPARCIA_MIESZKANCA.PLAN_AKTUALIZOWANY_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long planAktualizowanyId;

    /**
     * PLAN_WSPARCIA_MIESZKANCA.PRACOWNIK_PK_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long pracownikPkId;

    /**
     * PLAN_WSPARCIA_MIESZKANCA.DATA_OD
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date dataOd;

    /**
     * PLAN_WSPARCIA_MIESZKANCA.DATA_DO
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date dataDo;

    /**
     * PLAN_WSPARCIA_MIESZKANCA.DATA_WAZNOSCI
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date dataWaznosci;

    /**
     * PLAN_WSPARCIA_MIESZKANCA.NR
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String nr;

    /**
     * PLAN_WSPARCIA_MIESZKANCA.OPIS
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String opis;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return PLAN_WSPARCIA_MIESZKANCA.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * PLAN_WSPARCIA_MIESZKANCA.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return PLAN_WSPARCIA_MIESZKANCA.EWIDENCJA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getEwidencjaId() {
        return ewidencjaId;
    }

    /**
     * PLAN_WSPARCIA_MIESZKANCA.EWIDENCJA_ID
     *
     * @param ewidencjaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setEwidencjaId(Long ewidencjaId) {
        this.ewidencjaId = ewidencjaId;
    }

    /**
     * @return PLAN_WSPARCIA_MIESZKANCA.PLAN_AKTUALIZOWANY_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getPlanAktualizowanyId() {
        return planAktualizowanyId;
    }

    /**
     * PLAN_WSPARCIA_MIESZKANCA.PLAN_AKTUALIZOWANY_ID
     *
     * @param planAktualizowanyId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setPlanAktualizowanyId(Long planAktualizowanyId) {
        this.planAktualizowanyId = planAktualizowanyId;
    }

    /**
     * @return PLAN_WSPARCIA_MIESZKANCA.PRACOWNIK_PK_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getPracownikPkId() {
        return pracownikPkId;
    }

    /**
     * PLAN_WSPARCIA_MIESZKANCA.PRACOWNIK_PK_ID
     *
     * @param pracownikPkId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setPracownikPkId(Long pracownikPkId) {
        this.pracownikPkId = pracownikPkId;
    }

    /**
     * @return PLAN_WSPARCIA_MIESZKANCA.DATA_OD
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getDataOd() {
        return dataOd;
    }

    /**
     * PLAN_WSPARCIA_MIESZKANCA.DATA_OD
     *
     * @param dataOd
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDataOd(Date dataOd) {
        this.dataOd = dataOd;
    }

    /**
     * @return PLAN_WSPARCIA_MIESZKANCA.DATA_DO
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getDataDo() {
        return dataDo;
    }

    /**
     * PLAN_WSPARCIA_MIESZKANCA.DATA_DO
     *
     * @param dataDo
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDataDo(Date dataDo) {
        this.dataDo = dataDo;
    }

    /**
     * @return PLAN_WSPARCIA_MIESZKANCA.DATA_WAZNOSCI
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getDataWaznosci() {
        return dataWaznosci;
    }

    /**
     * PLAN_WSPARCIA_MIESZKANCA.DATA_WAZNOSCI
     *
     * @param dataWaznosci
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDataWaznosci(Date dataWaznosci) {
        this.dataWaznosci = dataWaznosci;
    }

    /**
     * @return PLAN_WSPARCIA_MIESZKANCA.NR
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getNr() {
        return nr;
    }

    /**
     * PLAN_WSPARCIA_MIESZKANCA.NR
     *
     * @param nr
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setNr(String nr) {
        this.nr = nr == null ? null : nr.trim();
    }

    /**
     * @return PLAN_WSPARCIA_MIESZKANCA.OPIS
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getOpis() {
        return opis;
    }

    /**
     * PLAN_WSPARCIA_MIESZKANCA.OPIS
     *
     * @param opis
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setOpis(String opis) {
        this.opis = opis == null ? null : opis.trim();
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        PlanWsparciaMieszkanca other = (PlanWsparciaMieszkanca) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getEwidencjaId() == null ? other.getEwidencjaId() == null : this.getEwidencjaId().equals(other.getEwidencjaId()))
            && (this.getPlanAktualizowanyId() == null ? other.getPlanAktualizowanyId() == null : this.getPlanAktualizowanyId().equals(other.getPlanAktualizowanyId()))
            && (this.getPracownikPkId() == null ? other.getPracownikPkId() == null : this.getPracownikPkId().equals(other.getPracownikPkId()))
            && (this.getDataOd() == null ? other.getDataOd() == null : this.getDataOd().equals(other.getDataOd()))
            && (this.getDataDo() == null ? other.getDataDo() == null : this.getDataDo().equals(other.getDataDo()))
            && (this.getDataWaznosci() == null ? other.getDataWaznosci() == null : this.getDataWaznosci().equals(other.getDataWaznosci()))
            && (this.getNr() == null ? other.getNr() == null : this.getNr().equals(other.getNr()))
            && (this.getOpis() == null ? other.getOpis() == null : this.getOpis().equals(other.getOpis()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getEwidencjaId() == null) ? 0 : getEwidencjaId().hashCode());
        result = prime * result + ((getPlanAktualizowanyId() == null) ? 0 : getPlanAktualizowanyId().hashCode());
        result = prime * result + ((getPracownikPkId() == null) ? 0 : getPracownikPkId().hashCode());
        result = prime * result + ((getDataOd() == null) ? 0 : getDataOd().hashCode());
        result = prime * result + ((getDataDo() == null) ? 0 : getDataDo().hashCode());
        result = prime * result + ((getDataWaznosci() == null) ? 0 : getDataWaznosci().hashCode());
        result = prime * result + ((getNr() == null) ? 0 : getNr().hashCode());
        result = prime * result + ((getOpis() == null) ? 0 : getOpis().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", ewidencjaId=").append(ewidencjaId);
        sb.append(", planAktualizowanyId=").append(planAktualizowanyId);
        sb.append(", pracownikPkId=").append(pracownikPkId);
        sb.append(", dataOd=").append(dataOd);
        sb.append(", dataDo=").append(dataDo);
        sb.append(", dataWaznosci=").append(dataWaznosci);
        sb.append(", nr=").append(nr);
        sb.append(", opis=").append(opis);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/PlanWsparciaMieszkanca.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class PlanWsparciaMieszkanca extends GenericDPSObject {
    /**
     * PLAN_WSPARCIA_MIESZKANCA.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * PLAN_WSPARCIA_MIESZKANCA.EWIDENCJA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long ewidencjaId;

    /**
     * PLAN_WSPARCIA_MIESZKANCA.PLAN_AKTUALIZOWANY_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long planAktualizowanyId;

    /**
     * PLAN_WSPARCIA_MIESZKANCA.PRACOWNIK_PK_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long pracownikPkId;

    /**
     * PLAN_WSPARCIA_MIESZKANCA.DATA_OD
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date dataOd;

    /**
     * PLAN_WSPARCIA_MIESZKANCA.DATA_DO
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date dataDo;

    /**
     * PLAN_WSPARCIA_MIESZKANCA.DATA_WAZNOSCI
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date dataWaznosci;

    /**
     * PLAN_WSPARCIA_MIESZKANCA.NR
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String nr;

    /**
     * PLAN_WSPARCIA_MIESZKANCA.OPIS
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String opis;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return PLAN_WSPARCIA_MIESZKANCA.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * PLAN_WSPARCIA_MIESZKANCA.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return PLAN_WSPARCIA_MIESZKANCA.EWIDENCJA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getEwidencjaId() {
        return ewidencjaId;
    }

    /**
     * PLAN_WSPARCIA_MIESZKANCA.EWIDENCJA_ID
     *
     * @param ewidencjaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setEwidencjaId(Long ewidencjaId) {
        this.ewidencjaId = ewidencjaId;
    }

    /**
     * @return PLAN_WSPARCIA_MIESZKANCA.PLAN_AKTUALIZOWANY_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getPlanAktualizowanyId() {
        return planAktualizowanyId;
    }

    /**
     * PLAN_WSPARCIA_MIESZKANCA.PLAN_AKTUALIZOWANY_ID
     *
     * @param planAktualizowanyId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setPlanAktualizowanyId(Long planAktualizowanyId) {
        this.planAktualizowanyId = planAktualizowanyId;
    }

    /**
     * @return PLAN_WSPARCIA_MIESZKANCA.PRACOWNIK_PK_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getPracownikPkId() {
        return pracownikPkId;
    }

    /**
     * PLAN_WSPARCIA_MIESZKANCA.PRACOWNIK_PK_ID
     *
     * @param pracownikPkId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setPracownikPkId(Long pracownikPkId) {
        this.pracownikPkId = pracownikPkId;
    }

    /**
     * @return PLAN_WSPARCIA_MIESZKANCA.DATA_OD
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getDataOd() {
        return dataOd;
    }

    /**
     * PLAN_WSPARCIA_MIESZKANCA.DATA_OD
     *
     * @param dataOd
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDataOd(Date dataOd) {
        this.dataOd = dataOd;
    }

    /**
     * @return PLAN_WSPARCIA_MIESZKANCA.DATA_DO
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getDataDo() {
        return dataDo;
    }

    /**
     * PLAN_WSPARCIA_MIESZKANCA.DATA_DO
     *
     * @param dataDo
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDataDo(Date dataDo) {
        this.dataDo = dataDo;
    }

    /**
     * @return PLAN_WSPARCIA_MIESZKANCA.DATA_WAZNOSCI
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getDataWaznosci() {
        return dataWaznosci;
    }

    /**
     * PLAN_WSPARCIA_MIESZKANCA.DATA_WAZNOSCI
     *
     * @param dataWaznosci
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDataWaznosci(Date dataWaznosci) {
        this.dataWaznosci = dataWaznosci;
    }

    /**
     * @return PLAN_WSPARCIA_MIESZKANCA.NR
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getNr() {
        return nr;
    }

    /**
     * PLAN_WSPARCIA_MIESZKANCA.NR
     *
     * @param nr
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setNr(String nr) {
        this.nr = nr == null ? null : nr.trim();
    }

    /**
     * @return PLAN_WSPARCIA_MIESZKANCA.OPIS
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getOpis() {
        return opis;
    }

    /**
     * PLAN_WSPARCIA_MIESZKANCA.OPIS
     *
     * @param opis
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setOpis(String opis) {
        this.opis = opis == null ? null : opis.trim();
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        PlanWsparciaMieszkanca other = (PlanWsparciaMieszkanca) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getEwidencjaId() == null ? other.getEwidencjaId() == null : this.getEwidencjaId().equals(other.getEwidencjaId()))
            && (this.getPlanAktualizowanyId() == null ? other.getPlanAktualizowanyId() == null : this.getPlanAktualizowanyId().equals(other.getPlanAktualizowanyId()))
            && (this.getPracownikPkId() == null ? other.getPracownikPkId() == null : this.getPracownikPkId().equals(other.getPracownikPkId()))
            && (this.getDataOd() == null ? other.getDataOd() == null : this.getDataOd().equals(other.getDataOd()))
            && (this.getDataDo() == null ? other.getDataDo() == null : this.getDataDo().equals(other.getDataDo()))
            && (this.getDataWaznosci() == null ? other.getDataWaznosci() == null : this.getDataWaznosci().equals(other.getDataWaznosci()))
            && (this.getNr() == null ? other.getNr() == null : this.getNr().equals(other.getNr()))
            && (this.getOpis() == null ? other.getOpis() == null : this.getOpis().equals(other.getOpis()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getEwidencjaId() == null) ? 0 : getEwidencjaId().hashCode());
        result = prime * result + ((getPlanAktualizowanyId() == null) ? 0 : getPlanAktualizowanyId().hashCode());
        result = prime * result + ((getPracownikPkId() == null) ? 0 : getPracownikPkId().hashCode());
        result = prime * result + ((getDataOd() == null) ? 0 : getDataOd().hashCode());
        result = prime * result + ((getDataDo() == null) ? 0 : getDataDo().hashCode());
        result = prime * result + ((getDataWaznosci() == null) ? 0 : getDataWaznosci().hashCode());
        result = prime * result + ((getNr() == null) ? 0 : getNr().hashCode());
        result = prime * result + ((getOpis() == null) ? 0 : getOpis().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", ewidencjaId=").append(ewidencjaId);
        sb.append(", planAktualizowanyId=").append(planAktualizowanyId);
        sb.append(", pracownikPkId=").append(pracownikPkId);
        sb.append(", dataOd=").append(dataOd);
        sb.append(", dataDo=").append(dataDo);
        sb.append(", dataWaznosci=").append(dataWaznosci);
        sb.append(", nr=").append(nr);
        sb.append(", opis=").append(opis);
        sb.append("]");
        return sb.toString();
    }
}
